import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

abstract class Perfume {
    protected String name;
    protected double price;
    protected String brand;
    protected int volume;

    public Perfume(String name, double price, String brand, int volume) {
        this.name = name;
        this.price = price;
        this.brand = brand;
        this.volume = volume;
    }

    // getters and setters
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public double getPrice() {
        return price;
    }

    public void setPrice(double price) {
        this.price = price;
    }

    public String getBrand() {
        return brand;
    }

    public void setBrand(String brand) {
        this.brand = brand;
    }

    public int getVolume() {
        return volume;
    }

    public void setVolume(int volume) {
        this.volume = volume;
    }

    public abstract double calculateDiscountedPrice();
}

class EauDeToilette extends Perfume {
    public EauDeToilette(String name, double price, String brand, int volume) {
        super(name, price, brand, volume);
    }

    public double calculateDiscountedPrice() {
        // 10% discount for EauDeToilette
        return getPrice() * 0.9;
    }
}

class EauDeParfum extends Perfume {
    public EauDeParfum(String name, double price, String brand, int volume) {
        super(name, price, brand, volume);
    }

    @Override
    public double calculateDiscountedPrice() {
        // 15% discount for EauDeParfum
        return getPrice() * 0.85;
    }
}

class PerfumeShopMain {
    public static void main(String[] args) {
        List<Perfume> perfumes = new ArrayList<>();

       System.out.println("Enter perfumes information (type 'END' to finish):");
        Scanner scanner = new Scanner(System.in);
        while (true) {
            String input = scanner.nextLine();
            if (input.equals("END"))
                break;

            String[] tokens = input.split(" ");

            if (tokens.length >= 2) {
                String typeProduct = tokens[0];
                double productionPrice;

                try {
                    productionPrice = Double.parseDouble(tokens[1]);
                } catch (NumberFormatException e) {
                    System.out.println("Invalid production price. Skipping...");
                    continue;
                }

                Perfume perfume;
                if (typeProduct.equals("EauDeToilette")) {
                    perfume = new EauDeToilette("EauDeToilette", productionPrice, "Brand1", 100);
                } else if (typeProduct.equals("EauDeParfum")) {
                    perfume = new EauDeParfum("EauDeParfum", productionPrice, "Brand2", 50);
                } else {
                    System.out.println("Invalid perfume type. Skipping...");
                    continue;
                }

                perfumes.add(perfume);
            } else {
                System.out.println("Invalid input. Skipping...");
            }
        }

       System.out.println("\nAll perfumes:");
        for (Perfume perfume : perfumes) {
            System.out.printf("%s by %s - Original Price: $%.2f, Discounted Price: $%.2f%n",
                    perfume.getName(), perfume.getBrand(), perfume.getPrice(), perfume.calculateDiscountedPrice());
        }
    }
}
