using System;
using System.Collections.Generic;

abstract class Perfume
{
    protected string name;
    protected double price;
    protected string brand;
    protected int volume;

    public Perfume(string name, double price, string brand, int volume)
    {
        this.name = name;
        this.price = price;
        this.brand = brand;
        this.volume = volume;
    }

    // getters and setters
    public string Name
    {
        get { return name; }
        set { name = value; }
    }

    public double Price
    {
        get { return price; }
        set { price = value; }
    }

    public string Brand
    {
        get { return brand; }
        set { brand = value; }
    }

    public int Volume
    {
        get { return volume; }
        set { volume = value; }
    }

    public abstract double CalculateDiscountedPrice();
}

class EauDeToilette : Perfume
{
    public EauDeToilette(string name, double price, string brand, int volume) : base(name, price, brand, volume)
    {
    }

    public override double CalculateDiscountedPrice()
    {
        // 10% discount for EauDeToilette
        return Price * 0.9;
    }
}

class EauDeParfum : Perfume
{
    public EauDeParfum(string name, double price, string brand, int volume) : base(name, price, brand, volume)
    {
    }

    public override double CalculateDiscountedPrice()
    {
        // 15% discount for EauDeParfum
        return Price * 0.85;
    }
}

class PerfumeShopMain
{
    static void Main()
    {
        List<Perfume> perfumes = new List<Perfume>();

        // Въвеждане на парфюми
        Console.WriteLine("Enter perfumes information (type 'END' to finish):");
        while (true)
        {
            string input = Console.ReadLine();
            if (input == "END")
                break;

            string[] tokens = input.Split(' ');

            if (tokens.Length >= 2)
            {
                string typeProduct = tokens[0];
                double productionPrice;

                if (double.TryParse(tokens[1], out productionPrice))
                {
                    Perfume perfume;
                    if (typeProduct == "EauDeToilette")
                    {
                        perfume = new EauDeToilette("EauDeToilette", productionPrice, "Brand1", 100);
                    }
                    else if (typeProduct == "EauDeParfum")
                    {
                        perfume = new EauDeParfum("EauDeParfum", productionPrice, "Brand2", 50);
                    }
                    else
                    {
                        Console.WriteLine("Invalid perfume type. Skipping...");
                        continue;
                    }

                    perfumes.Add(perfume);
                }
                else
                {
                    Console.WriteLine("Invalid production price. Skipping...");
                }
            }
            else
            {
                Console.WriteLine("Invalid input. Skipping...");
            }
        }

        Console.WriteLine("\nAll perfumes:");
        foreach (Perfume perfume in perfumes)
        {
            Console.WriteLine($"{perfume.Name} by {perfume.Brand} - Original Price: ${perfume.Price}, Discounted Price: ${perfume.CalculateDiscountedPrice():F2}");
        }
    }
}
